@@ -4,9 +4,9 @@ TinUI风格对话框
 from tkinter import Tk, Toplevel
 
 try:
-    from .TinUI import BasicTinUI
+    from .TinUI import BasicTinUI, TinUIXml
 except:
-    from TinUI import BasicTinUI
+    from TinUI import BasicTinUI, TinUIXml
 
 
 
@@ -47,7 +47,7 @@ class Dialog(Toplevel):
                 'online':'#e5e5e5'
             }
             self.entryargs = {
-                'fg':'#606060',
+                'fg':'#1b1b1b',
                 'bg':'#fbfbfb',
                 'activefg':'#1a1a1a',
                 'activebg':'#f6f6f6',
@@ -57,7 +57,7 @@ class Dialog(Toplevel):
                 'activeline':'#e5e5e5',
                 'insert':'#000000',
                 'outline':'#868686',
-                'onoutline':'#3041d8',
+                'onoutline':'#0067C0',
             }
             self.listargs = {
                 'fg':'#1a1a1a',
@@ -66,7 +66,7 @@ class Dialog(Toplevel):
                 'activebg':'#e9e9e9',
                 'onfg':'#191919',
                 'onbg':'#ececec',
-                'sel':'#b4bbea',
+                'sel':'#91C1E6',
                 'scrollbg':'#f9f9f9',
                 'scrollcolor':'#8d8d8d',
                 'scrollon':'#8a8a8a'
@@ -107,7 +107,7 @@ class Dialog(Toplevel):
                 'line':'#303030',
                 'activeline':'#202020',
                 'outline':'#9a9a9a',
-                'onoutline':'#b2b8f2',
+                'onoutline':'#4CC2FF',
                 'insert':'#e0e0e0',
             }
             self.listargs = {
@@ -117,7 +117,7 @@ class Dialog(Toplevel):
                 'activebg':'#373737',
                 'onfg':'#ffffff',
                 'onbg':'#333333',
-                'sel':'#465097',
+                'sel':'#115990',
                 'scrollbg':'#2e2e2e',
                 'scrollcolor':'#9f9f9f',
                 'scrollon':'#a0a0a0'
@@ -373,6 +373,70 @@ class Dialog(Toplevel):
         self.wait_window(self)
 
         return self.result
+    
+    def initial_xml_load(self,title,xml,funcdict:dict={},data:dict={},yestext='OK',notext='Cancel',yescallback=None,nocallback=None,nonecallback=None,tinuitheme=None):
+        """
+        自定义XML内容
+        """
+        YES=yestext
+        NO=notext
+        self.tinui['bg'] = self.background
+
+        if tinuitheme:
+            self.tinuitheme = tinuitheme(self.tinui)
+            self.tinuixml = TinUIXml(self.tinuitheme)
+        else:
+            self.tinuixml = TinUIXml(self.tinui)
+        self.tinuixml.funcs.update(funcdict)
+        self.tinuixml.datas.update(data)
+
+        self.title(title)
+        self.protocol('WM_DELETE_WINDOW',lambda:(nonecallback() ,self.return_msg(None)))
+
+        self.tinuixml.loadxml(xml)
+
+        content_bbox=self.tinui.bbox('all')
+        btn_width=(content_bbox[2]-content_bbox[0])/2
+        button_width=btn_width-10 if btn_width>110 else 100
+        button_endy=self._endy()+15
+        yesbutton_uid=self.tinui.add_button2(((content_bbox[0]+content_bbox[2])/2-5,button_endy),text=YES,minwidth=button_width,command=lambda e:(yescallback() ,self.return_msg(True)),anchor='ne',**self.buttonargs)[-1]
+        yb_coords = self.tinui.coords(yesbutton_uid)
+        nobutton_uid=self.tinui.add_button2(((content_bbox[0]+content_bbox[2])/2+5,button_endy),text=NO,minwidth=button_width,command=lambda e:(nocallback() ,self.return_msg(False)),anchor='nw',**self.buttonargs)[-1]
+        nb_coords = self.tinui.coords(nobutton_uid)
+        self.tinui.add_back((),(yesbutton_uid,nobutton_uid),bg=self.barback,fg=self.barback,linew=9)
+
+        def return_focus(event):
+            if now_focus == 'yes':
+                yescallback()
+                self.return_msg(True)
+            else:
+                nocallback()
+                self.return_msg(False)
+        def focus_left(event):
+            nonlocal now_focus
+            if now_focus == 'yes':
+                return
+            now_focus = 'yes'
+            self.tinui.coords(focus_button, yb_coords)
+        def focus_right(event):
+            nonlocal now_focus
+            if now_focus == 'no':
+                return
+            now_focus = 'no'
+            self.tinui.coords(focus_button, nb_coords)
+
+        focus_button = self.tinui.create_polygon(yb_coords, width=11, fill=self.barback, outline=self.selback)
+        self.tinui.lower(focus_button, yesbutton_uid)
+        now_focus = 'yes'
+        self.bind('<Return>', return_focus)
+        self.bind('<space>', return_focus)
+        self.bind('<Left>', focus_left)
+        self.bind('<Right>', focus_right)
+
+        self.entryw = None
+
+    def initial_xml_init(self):
+        return self.load_window()
 
 
 
@@ -464,4 +528,21 @@ if __name__=='__main__':
     ask_float(root,'test','input float')
     c=ask_choice(root,'test','choose one',('a','b','c'),theme='dark')
     print(c)
+    xml_data = 0
+    def xml_func(e):
+        global xml_data
+        xml_data = 1
+    func_dict = {'func':xml_func}
+    d=Dialog(root,'xml')
+    d.initial_xml_load('test xml dialog','<tinui><line>'
+    '<button text="click to change data value" command="self.funcs[\'func\']"></button>'
+    '</line></tinui>',
+    funcdict=func_dict,yescallback=lambda:print('yes'),nocallback=lambda:print('no'),nonecallback=lambda:print('none'))
+    dr=d.initial_xml_init()
+    if dr:
+        print(f'yes with {xml_data}')
+    elif dr==False:
+        print(f'no with {xml_data}')
+    elif dr==None:
+        print(f'none with {xml_data}')
     root.mainloop()
\ No newline at end of file
