@@ -1,4 +1,4 @@
-from .TinUI import BasicTinUI, TinUI, TinUIXml, TinUITheme
+from .TinUI import BasicTinUI, TinUI, TinUIXml, TinUITheme, ExpandPanel, VerticalPanel, HorizonPanel
 from .TinUIDialog import show_msg, show_info, show_success, show_warning, show_error, show_question,\
     ask_string, ask_integer, ask_float, ask_choice
 
