@@ -33,9 +33,9 @@ class TinUIDark(TinUITheme):
     def add_checkbutton(self,pos,*arg,**kw):
         return self.ui.add_checkbutton(pos,*arg,**{
             **{
-                'fontfg':'#ffffff','fg':'#999999','bg':'#1d1d1d',
-                'activefg':'#9c9c9c','activebg':'#2a2a2a',
-                'onfg':'#010101','onbg':'#a3a8dc',
+                'fontfg':'#ffffff','fg':'#989898','bg':'#1d1d1d',
+                'activefg':'#9E9E9E','activebg':'#2a2a2a',
+                'onfg':'black','onbg':'#4CC2FF',
             },**kw})
 
     def add_label(self,pos,*arg,**kw):
@@ -52,7 +52,7 @@ class TinUIDark(TinUITheme):
                 'activefg':'#ffffff','activebg':'#323232',
                 'onfg':'#ffffff','onbg':'#1f1f1f',
                 'line':'#303030','activeline':'#303030',
-                'outline':'#9a9a9a','onoutline':'#b2b8f2','insert':'#e0e0e0',
+                'outline':'#9a9a9a','onoutline':'#4CC2FF','insert':'#e0e0e0',
             },**kw})
 
     def add_separate(self,pos,*arg,**kw):
@@ -71,27 +71,29 @@ class TinUIDark(TinUITheme):
     def add_link(self,pos,*arg,**kw):
         return self.ui.add_link(pos,*arg,**{
             **{
-                'fg':'#d7d9f9',
-                'activefg':'#d7d9f9','activebg':'#2d2d2d',
+                'fg':'#99EBFF',
+                'activefg':'#99EBFF','activebg':'#2d2d2d',
             },**kw})
 
     def add_waitbar1(self,pos,*arg,**kw):
-        return self.ui.add_waitbar1(pos,*arg,**{
-            **{
-                'fg':'#b2b8f2','bg':'#202020','okfg':'#b2b8f2','bd':5,
-            },**kw})
+        # return self.ui.add_waitbar1(pos,*arg,**{
+        #     **{
+        #         'fg':'#b2b8f2','bg':'#202020','okfg':'#b2b8f2','bd':5,
+        #     },**kw})
+        ...
 
     def add_labelframe(self,uids:tuple,*arg,**kw):
         return self.ui.add_labelframe(uids,*arg,**{
             **{
-                'fg':'#ffffff','bg':'#272727',
+                'fg':'#1D1D1D','bg':'#272727',
             },**kw})
 
     def add_waitbar2(self,pos,*arg,**kw):
-        return self.ui.add_waitbar2(pos,*arg,**{
-            **{
-                'fg':'#b2b8f2','bg':'#202020','okcolor':'#6ccb5f',
-            },**kw})
+        # return self.ui.add_waitbar2(pos,*arg,**{
+        #     **{
+        #         'fg':'#b2b8f2','bg':'#202020','okcolor':'#6ccb5f',
+        #     },**kw})
+        ...
 
     def add_combobox(self,pos,*arg,**kw):
         return self.ui.add_combobox(pos,*arg,**{
@@ -99,15 +101,15 @@ class TinUIDark(TinUITheme):
                 'fg':'#cfcfcf','bg':'#2d2d2d','outline':'#303030',
                 'activefg':'#ffffff','activebg':'#323232','activeline':'#303030',
                 'onfg':'#cecece','onbg':'#272727','online':'#303030',
-                'listfg':'#ffffff','listactivefg':'#ffffff','listactivebg':'#373737',
-                'listonfg':'#ffffff','listonbg':'#333333','listsel':'#465097',
+                'listfg':'#ffffff','listactivefg':'#ffffff','listactivebg':'#383838',
+                'listonfg':'#D1D1D1','listonbg':'#343434','listsel':'#383838',
                 'scrollbg':'#2c2c2c','scrollcolor':'#9f9f9f','scrollon':'#a0a0a0',
             },**kw})
 
     def add_progressbar(self,pos,*arg,**kw):
         return self.ui.add_progressbar(pos,*arg,**{
             **{
-                'fg':'#9a9a9a','bg':'#b2b8f2','back':'#202020',
+                'fg':'#9a9a9a','bg':'#4CC2FF','back':'#202020',
                 'fontc':'#0000ff',
             },**kw})
 
@@ -123,18 +125,19 @@ class TinUIDark(TinUITheme):
             **{
                 'fg':'#cccccc','bg':'#1d1d1d',
                 'activefg':'#cfcfcf','activebg':'#2a2a2a',
-                'onactivefg':'#000000','onactivebg':'#8e93c2',
-                'onfg':'#000000','onbg':'#b2b8f2',
+                'onactivefg':'#000000','onactivebg':'#47B1E8',
+                'onfg':'#000000','onbg':'#4CC2FF',
             },**kw})
 
     def add_spinbox(self,pos,*arg,**kw):
-        return self.ui.add_spinbox(pos,
-              fg='#ffffff',bg='#2d2d2d',line='#303030',
-              activefg='#c0c0c0',activebg='#323232',
-              boxfg='#cfcfcf',boxbg='#2c2c2c',
-              boxactivefg='#d2d2d2',boxactivebg='#383838',
-              onfg='#9f9f9f',onbg='#343434',
-                                   *arg,**kw)
+        return self.ui.add_spinbox(pos,**{
+            **{
+              'fg':'#ffffff','bg':'#2d2d2d','line':'#303030',
+              'activefg':'#c0c0c0','activebg':'#323232',
+              'boxfg':'#cfcfcf','boxbg':'#2c2c2c',
+              'boxactivefg':'#d2d2d2','boxactivebg':'#383838',
+              'onfg':'#9f9f9f','onbg':'#343434',
+            },**kw})
 
     def add_image(self,pos,*arg,**kw):
         return self.ui.add_image(pos,*arg,**kw)
@@ -142,15 +145,16 @@ class TinUIDark(TinUITheme):
     def add_scalebar(self,pos,*arg,**kw):
         return self.ui.add_scalebar(pos,*arg,**{
             **{
-                'fg':'#b2b8f2','bg':'#9a9a9a','activefg':'#8e93c2',
-                'buttonbg':'#454545','buttonoutline':'#303030',
+                'fg':'#4CC2FF','bg':'#9a9a9a','activefg':'#4BB5EC',
+                'buttonbg':'#454545','buttonoutline':'#353535',
             },**kw})
 
     def add_info(self,pos,*arg,**kw):
-        return self.ui.add_info(pos,*arg,**{
-            **{
-                'fg':'#b2b8f2','bg':'#2d2d2d','info_fg':'#ffffff',
-            },**kw})
+        # return self.ui.add_info(pos,*arg,**{
+        #     **{
+        #         'fg':'#b2b8f2','bg':'#2d2d2d','info_fg':'#ffffff',
+        #     },**kw})
+        ...
 
     def add_menubar(self,uid,*arg,**kw):
         return self.ui.add_menubar(uid,*arg,**{
@@ -169,14 +173,14 @@ class TinUIDark(TinUITheme):
     def add_waitbar3(self,pos,*arg,**kw):
         return self.ui.add_waitbar3(pos,*arg,**{
             **{
-                'fg':'#b2b8f2','bg':'#202020','okcolor':'#b2b8f2',
+                'fg':'#4CC2FF','bg':'#202020','okcolor':'#4CC2FF',
             },**kw})
 
     def add_textbox(self,pos,*arg,**kw):
         return self.ui.add_textbox(pos,*arg,**{
             **{
                 'fg':'#ffffff','bg':'#2d2d2d',
-                'outline':'#9a9a9a','onoutline':'#b2b8f2',
+                'outline':'#9a9a9a','onoutline':'#4CC2FF',
                 'scrollbg':'#2e2e2e','scrollcolor':'#9f9f9f','scrollon':'#a0a0a0',
             },**kw})
 
@@ -191,16 +195,16 @@ class TinUIDark(TinUITheme):
             **{
                 'bg':'#2b2b2b','fg':'white',
                 'activefg':'#ffffff','activebg':'#373737',
-                'onfg':'#ffffff','onbg':'#333333','sel':'#465097',
+                'onfg':'#ffffff','onbg':'#333333','sel':'#115990',
                 'scrollbg':'#2e2e2e','scrollcolor':'#9f9f9f','scrollon':'#a0a0a0',
             },**kw})
 
-    def add_canvas(self,pos,*arg,**kw):
-        return self.ui.add_canvas(pos,*arg,**{
-            **{
-                'outline':'#808080','linew':1,
-                'scrollbg':'#2e2e2e','scrollcolor':'#9f9f9f','scrollon':'#a0a0a0',
-            },**kw})
+    # def add_canvas(self,pos,*arg,**kw):
+    #     return self.ui.add_canvas(pos,*arg,**{
+    #         **{
+    #             'outline':'#808080','linew':1,
+    #             'scrollbg':'#2e2e2e','scrollcolor':'#9f9f9f','scrollon':'#a0a0a0',
+    #         },**kw})
     
     def add_pipspager(self,pos,*arg,**kw):
         return self.ui.add_pipspager(pos,*arg,**{
@@ -224,7 +228,7 @@ class TinUIDark(TinUITheme):
         return self.ui.add_ratingbar(pos,*arg,**{
             **{
                 'fg':'#cccccc','bg':'#202020',
-                'onfg':'#b2b8f2','onbg':'#b2b8f2',
+                'onfg':'#4CC2FF','onbg':'#4CC2FF',
             },**kw})
 
     def add_radiobox(self,pos,*arg,**kw):
@@ -232,7 +236,7 @@ class TinUIDark(TinUITheme):
             **{
                 'fontfg':'#ffffff','fg':'#939393','bg':'#2a2a2a',
                 'activefg':'#959595','activebg':'#2a2a2a',
-                'onfg':'#a3a8dc','onbg':'#000000',
+                'onfg':'#4CC2FF','onbg':'#000000',
             },**kw})
 
     def add_notecard(self,pos,*arg,**kw):
@@ -246,7 +250,7 @@ class TinUIDark(TinUITheme):
         return self.ui.add_pivot(pos,*arg,**{
             **{
                 'fg':'#a6a6a6','bg':'',
-                'activefg':'#ffffff','activecolor':'#5969e0',
+                'activefg':'#ffffff','activecolor':'#4CC2FF',
             },**kw})
 
     def add_button2(self,pos,*arg,**kw):
@@ -257,6 +261,24 @@ class TinUIDark(TinUITheme):
                 'line':'#303030','linew':1,'activeline':'#202020',
                 'onfg':'#cecece','onbg':'#272727','online':'#303030',
             },**kw})
+    
+    def add_accentbutton(self,pos,*arg,**kw):
+        return self.ui.add_accentbutton(pos,*arg,**{
+            **{
+                'fg':'#000000','bg':'#4CC2FF',
+                'activefg':'#000000','activebg':'#47B1E8',
+                'line':'#5AC7FF','linew':1,'activeline':'#2B80CA',
+                'onfg':'#215069','onbg':'#42A1D2','online':'#42A1D2',
+            },**kw})
+    
+    def add_toolbutton(self,pos,*arg,**kw):
+        return self.ui.add_toolbutton(pos,*arg,**{
+            **{
+                'fg':'#FFFFFF','bg':'#202020',
+                'activefg':'#FFFFFF','activebg':'#2D2D2D',
+                'line':'#202020','linew':1,'activeline':'#2D2D2D',
+                'onfg':'#CECECE','onbg':'#292929','online':'#292929',
+            },**kw})
 
     def add_expander(self,pos,*arg,**kw):
         return self.ui.add_expander(pos,*arg,**{
@@ -277,7 +299,7 @@ class TinUIDark(TinUITheme):
     def add_listview(self,pos,*arg,**kw):
         return self.ui.add_listview(pos,*arg,**{
             **{
-                'bg':'#202020','activebg':'#2d2d2d','oncolor':'#b2b8f2',
+                'bg':'#202020','activebg':'#2d2d2d','oncolor':'#4CC2FF',
                 'scrobg':'#2e2e2e','scroc':'#9a9a9a','scrooc':'#9f9f9f',
             },**kw})
 
@@ -286,30 +308,31 @@ class TinUIDark(TinUITheme):
             **{
                 'fg':'#ffffff','bg':'#202020',
                 'onfg':'#ffffff','onbg':'#2d2d2d',
-                'oncolor':'#b2b8f2','signcolor':'#9f9f9f',
+                'oncolor':'#4CC2FF','signcolor':'#9f9f9f',
             },**kw})
 
     def add_togglebutton(self,pos,*arg,**kw):
         return self.ui.add_togglebutton(pos,*arg,**{
             **{
-                'fg':'#ffffff','bg':'#2d2d2d','line':'#303030',
-                'activefg':'#000000','activebg':'#b2b8f2','activeline':'#b8bef3',
+                'fg':'#ffffff','bg':'#2d2d2d','line':"#303030",
+                'activefg':'#000000','activebg':'#4CC2FF','activeline':'#5AC7FF',
             },**kw})
     
     def add_swipecontrol(self,pos,*arg,**kw):
-        return self.ui.add_swipecontrol(pos,*arg,**{
-            **{
-                'fg':'#ffffff','bg':'#202020','line':'#2d2d2d',
-                'data':{'left':({'text':'✔️\nok','fg':'#000000','bg':'#a9a9a9','command':print},),
-                'right':({'text':'❌\nclose'},)},
-            },**kw})
+        # return self.ui.add_swipecontrol(pos,*arg,**{
+        #     **{
+        #         'fg':'#ffffff','bg':'#202020','line':'#2d2d2d',
+        #         'data':{'left':({'text':'✔️\nok','fg':'#000000','bg':'#a9a9a9','command':print},),
+        #         'right':({'text':'❌\nclose'},)},
+        #     },**kw})
+        ...
 
     def add_picker(self,pos,*arg,**kw):
         return self.ui.add_picker(pos,*arg,**{
             **{
                 'fg':'#cfcfcf','bg':'#2d2d2d','outline':'#3c3c3c',
                 'activefg':'#ffffff','activebg':'#323232',
-                'onfg':'#000000','onbg':'#a8ade4',
+                'onfg':'#000000','onbg':'#4CC2FF',
                 'buttonfg':'#ffffff','buttonbg':'#2d2d2d',
                 'buttonactivefg':'#ffffff','buttonactivebg':'#383838',
                 'buttononfg':'#ffffff','buttononbg':'#343434',
@@ -345,3 +368,9 @@ class TinUIDark(TinUITheme):
             **{
                 'fg':'#202020','bg':'#202020',
             },**kw})
+    
+    def add_breadcrumb(self,pos,*arg,**kw):
+        return self.ui.add_breadcrumb(pos,*arg,**{
+            **{
+                'fg':'#ffffff','bg':'#202020','activefg':'#cccccc'
+            },**kw})
