@@ -33,7 +33,7 @@ class TinUILight(TinUITheme):
             **{
                 'fontfg':'#1a1a1a','fg':'#868686','bg':'#ededed',
                 'activefg':'#868686','activebg':'#e5e5e5',
-                'onfg':'white','onbg':'#334ac0'
+                'onfg':'white','onbg':'#0067C0'
             },**kw})
 
     def add_label(self,pos,*arg,**kw):
@@ -50,7 +50,7 @@ class TinUILight(TinUITheme):
                 'activefg':'#1a1a1a','activebg':'#f6f6f6',
                 'onfg':'#000000','onbg':'#ffffff',
                 'line':'#e5e5e5','activeline':'#e5e5e5',
-                'outline':'#868686','onoutline':'#3041d8','insert':'#000000'
+                'outline':'#868686','onoutline':'#0067C0','insert':'#000000'
             },**kw})
 
     def add_separate(self,pos,*arg,**kw):
@@ -68,30 +68,32 @@ class TinUILight(TinUITheme):
     def add_link(self,pos,*arg,**kw):
         return self.ui.add_link(pos,*arg,**{
             **{
-                'fg':'#4f62ca',
-                'activefg':'red','activebg':'#eaeaea',
+                'fg':'#003E92',
+                'activefg':'#001A68','activebg':'#eaeaea',
             },**kw})
 
     def add_waitbar1(self,pos,*arg,**kw):
-        return self.ui.add_waitbar1(pos,*arg,**{
-            **{
-                'fg':'#3041d8',
-                'bg':'#f3f3f3',
-                'okfg':'#3041d8',
-                'bd':5
-            },**kw})
+        # return self.ui.add_waitbar1(pos,*arg,**{
+        #     **{
+        #         'fg':'#3041d8',
+        #         'bg':'#f3f3f3',
+        #         'okfg':'#3041d8',
+        #         'bd':5
+        #     },**kw})
+        ...
 
     def add_labelframe(self,uids:tuple,*arg,**kw):
         return self.ui.add_labelframe(uids,*arg,**{
             **{
-                'fg':'#1a1a1a','bg':'#f4f4f4',
+                'fg':'#E5E5E5','bg':'#f4f4f4',
             },**kw})
 
     def add_waitbar2(self,pos,*arg,**kw):
-        return self.ui.add_waitbar2(pos,*arg,**{
-            **{
-                'fg':'#3041d8','bg':'#f3f3f3','okcolor':'#0f7b0f',
-            },**kw})
+        # return self.ui.add_waitbar2(pos,*arg,**{
+        #     **{
+        #         'fg':'#3041d8','bg':'#f3f3f3','okcolor':'#0f7b0f',
+        #     },**kw})
+        ...
 
     def add_combobox(self,pos,*arg,**kw):
         return self.ui.add_combobox(pos,*arg,**{
@@ -101,15 +103,15 @@ class TinUILight(TinUITheme):
                 'activefg':'#1a1a1a','activebg':'#f6f6f6',
                 'activeline':'#cccccc',
                 'onfg':'#5d5d5d','onbg':'#f5f5f5','online':'#e5e5e5',
-                'listfg':'#1a1a1a','listactivefg':'#191919','listactivebg':'#e9e9e9',
-                'listonfg':'#191919','listonbg':'#ececec','listsel':'#b4bbea',
+                'listfg':'#1a1a1a','listactivefg':'#191919','listactivebg':'#F0F0F0',
+                'listonfg':'#5C5C5C','listonbg':'#F3F3F3','listsel':'#F0F0F0',
                 'scrollbg':'#f9f9f9','scrollcolor':'#999999','scrollon':'#89898b',
             },**kw})
 
     def add_progressbar(self,pos,*arg,**kw):
         return self.ui.add_progressbar(pos,*arg,**{
             **{
-                'fg':'#868686','bg':'#334ac0','back':'#f3f3f3',
+                'fg':'#868686','bg':'#0067C0','back':'#f3f3f3',
                 'fontc':'#79b8f8',
             },**kw})
 
@@ -145,15 +147,16 @@ class TinUILight(TinUITheme):
     def add_scalebar(self,pos,*arg,**kw):
         return self.ui.add_scalebar(pos,*arg,**{
             **{
-                'fg':'#3b50ba','bg':'#868686','activefg':'#3b50ba',
+                'fg':'#0067C0','bg':'#868686','activefg':'#1A76C6',
                 'buttonbg':'#ffffff','buttonoutline':'#cccccc',
             },**kw})
 
     def add_info(self,pos,*arg,**kw):
-        return self.ui.add_info(pos,*arg,**{
-            **{
-                'fg':'#0078d4','bg':'#f9f9f9','info_fg':'#1a1a1a',
-            },**kw})
+        # return self.ui.add_info(pos,*arg,**{
+        #     **{
+        #         'fg':'#0078d4','bg':'#f9f9f9','info_fg':'#1a1a1a',
+        #     },**kw})
+        ...
     
     def add_menubar(self,uid,*arg,**kw):
         return self.ui.add_menubar(uid,*arg,**{
@@ -172,14 +175,14 @@ class TinUILight(TinUITheme):
     def add_waitbar3(self,pos,*arg,**kw):
         return self.ui.add_waitbar3(pos,*arg,**{
             **{
-                'fg':'#3041d8','bg':'#f3f3f3','okcolor':'#3041d8',
+                'fg':'#0067C0','bg':'#f3f3f3','okcolor':'#0067C0',
             },**kw})
 
     def add_textbox(self,pos,*arg,**kw):
         return self.ui.add_textbox(pos,*arg,**{
             **{
                 'fg':'#1a1a1a','bg':'white',
-                'outline':'#868686','onoutline':'#3041d8',
+                'outline':'#868686','onoutline':'#0067C0',
                 'scrollbg':'#f9f9f9','scrollcolor':'#8d8d8d','scrollon':'#8a8a8a',
             },**kw})
 
@@ -195,16 +198,16 @@ class TinUILight(TinUITheme):
             **{
                 'fg':'#1a1a1a','bg':'#f2f2f2',
                 'activefg':'#191919','activebg':'#e9e9e9',
-                'onfg':'#191919','onbg':'#ececec','sel':'#b4bbea',
+                'onfg':'#191919','onbg':'#ececec','sel':'#91C1E6',
                 'scrollbg':'#f9f9f9','scrollcolor':'#8d8d8d','scrollon':'#8a8a8a',
             },**kw})
 
-    def add_canvas(self,pos,*arg,**kw):
-        return self.ui.add_canvas(pos,*arg,**{
-            **{
-                'outline':'#808080','linew':1,
-                'scrollbg':'#f9f9f9','scrollcolor':'#8d8d8d','scrollon':'#8a8a8a',
-            },**kw})
+    # def add_canvas(self,pos,*arg,**kw):
+    #     return self.ui.add_canvas(pos,*arg,**{
+    #         **{
+    #             'outline':'#808080','linew':1,
+    #             'scrollbg':'#f9f9f9','scrollcolor':'#8d8d8d','scrollon':'#8a8a8a',
+    #         },**kw})
 
     def add_pipspager(self,pos,*arg,**kw):
         return self.ui.add_pipspager(pos,*arg,**{
@@ -223,20 +226,20 @@ class TinUILight(TinUITheme):
                 'onfg':'#1a1a1a','onbg':'#f9f9f9',
                 'scrollbg':'#f9f9f9','scrollcolor':'#8d8d8d','scrollon':'#8a8a8a',
             },**kw})
+    
+    def add_ratingbar(self,pos,*arg,**kw):
+        return self.ui.add_ratingbar(pos,*arg,**{
+            **{
+                'fg':'#5d5d5d','bg':'#f3f3f3',
+                'onfg':'#0067C0','onbg':'#0067C0',
+            },**kw})
 
     def add_radiobox(self,pos,*arg,**kw):
         return self.ui.add_radiobox(pos,*arg,**{
             **{
                 'fontfg':'black','fg':'#8b8b8b','bg':'#ededed',
                 'activefg':'#898989','activebg':'#e5e5e5',
-                'onfg':'#3041d8','onbg':'#ffffff',
-            },**kw})
-
-    def add_ratingbar(self,pos,*arg,**kw):
-        return self.ui.add_ratingbar(pos,*arg,**{
-            **{
-                'fg':'#5d5d5d','bg':'#f3f3f3',
-                'onfg':'#3041d8','onbg':'#3041d8',
+                'onfg':'#0067C0','onbg':'#ffffff',
             },**kw})
 
     def add_notecard(self,pos,*arg,**kw):
@@ -250,7 +253,7 @@ class TinUILight(TinUITheme):
         return self.ui.add_pivot(pos,*arg,**{
             **{
                 'fg':'#616161','bg':'',
-                'activefg':'#000000','activecolor':'#5969e0',
+                'activefg':'#000000','activecolor':'#0067C0',
             },**kw})
 
     def add_button2(self,pos,*arg,**kw):
@@ -261,6 +264,24 @@ class TinUILight(TinUITheme):
                 'line':'#cccccc','linew':1,'activeline':'#cccccc',
                 'onfg':'#5d5d5d','onbg':'#f5f5f5','online':'#e5e5e5',
             },**kw})
+    
+    def add_accentbutton(self,pos,*arg,**kw):
+        return self.ui.add_accentbutton(pos,*arg,**{
+            **{
+                'fg':'#FFFFFF','bg':'#0067C0',
+                'activefg':'#FFFFFF','activebg':'#1975C5',
+                'line':'#1473C5','linew':1,'activeline':'#2B80CA',
+                'onfg':'#C2DAEF','onbg':'#3183CA','online':'#3183CA',
+            },**kw})
+    
+    def add_toolbutton(self,pos,*arg,**kw):
+        return self.ui.add_toolbutton(pos,*arg,**{
+            **{
+                'fg':'#1A1A1A','bg':'#F3F3F3',
+                'activefg':'#191919','activebg':'#EAEAEA',
+                'line':'#F3F3F3','linew':1,'activeline':'#EAEAEA',
+                'onfg':'#5A5A5A','onbg':'#EDEDED','online':'#EDEDED',
+            },**kw})
 
     def add_expander(self,pos,*arg,**kw):
         return self.ui.add_expander(pos,*arg,**{
@@ -281,7 +302,7 @@ class TinUILight(TinUITheme):
     def add_listview(self,pos,*arg,**kw):
         return self.ui.add_listview(pos,*arg,**{
             **{
-                'bg':'#f3f3f3','activebg':'#eaeaea','oncolor':'#3041d8',
+                'bg':'#f3f3f3','activebg':'#eaeaea','oncolor':'#0067C0',
                 'scrobg':'#f8f8f8','scroc':'#868686','scrooc':'#898989',
             },**kw})
 
@@ -290,30 +311,31 @@ class TinUILight(TinUITheme):
             **{
                 'fg':'#1a1a1a','bg':'#f3f3f3',
                 'onfg':'#1a1a1a','onbg':'#eaeaea',
-                'oncolor':'#3041d8','signcolor':'#8a8a8a',
+                'oncolor':'#0067C0','signcolor':'#8a8a8a',
             },**kw})
 
     def add_togglebutton(self,pos,*arg,**kw):
         return self.ui.add_togglebutton(pos,*arg,**{
             **{
                 'fg':'#1b1b1b','bg':'#fbfbfb','line':'#cccccc',
-                'activefg':'#f3f4fd','activebg':'#3041d8','activeline':'#5360de',
+                'activefg':'#f3f4fd','activebg':'#0067C0','activeline':'#2B80CA',
             },**kw})
     
     def add_swipecontrol(self,pos,*arg,**kw):
-        return self.ui.add_swipecontrol(pos,*arg,**{
-            **{
-                'fg':'#1a1a1a','bg':'#f3f3f3','line':'#fbfbfb',
-                'data':{'left':({'text':'✔️\nok','fg':'#202020','bg':'#bcbcbc','command':print},),
-                'right':({'text':'❌\nclose'},)},
-            },**kw})
+        # return self.ui.add_swipecontrol(pos,*arg,**{
+        #     **{
+        #         'fg':'#1a1a1a','bg':'#f3f3f3','line':'#fbfbfb',
+        #         'data':{'left':({'text':'✔️\nok','fg':'#202020','bg':'#bcbcbc','command':print},),
+        #         'right':({'text':'❌\nclose'},)},
+        #     },**kw})
+        ...
     
     def add_picker(self,pos,*arg,**kw):
         return self.ui.add_picker(pos,*arg,**{
             **{
                 'fg':'#1b1b1b','bg':'#fbfbfb',
                 'outline':'#ececec','activefg':'#1b1b1b',
-                'activebg':'#f6f6f6','onfg':'#eaecfb','onbg':'#3748d9',
+                'activebg':'#f6f6f6','onfg':'#eaecfb','onbg':'#0067C0',
                 'buttonfg':'#1a1a1a','buttonbg':'#fbfbfb',
                 'buttonactivefg':'#1a1a1a','buttonactivebg':'#f0f0f0',
                 'buttononfg':'#1a1a1a','buttononbg':'#f3f3f3',
@@ -347,3 +369,9 @@ class TinUILight(TinUITheme):
             **{
                 'fg':'#f3f3f3','bg':'#f3f3f3',
             },**kw})
+    
+    def add_breadcrumb(self,pos,*arg,**kw):
+        return self.ui.add_breadcrumb(pos,*arg,**{
+            **{
+                'fg':'#1a1a1a','bg':'#f3f3f3','activefg':'#5c5c5c'
+            },**kw})
